@@ -22,7 +22,7 @@ import time
 from string import Template
 
 class MongoInitializer(object):
-    def __init__(self):
+    def __init__(self, system):
         """
         Create a new initializer
         Param user The user login for the git repo
@@ -163,6 +163,7 @@ class MongoInitializer(object):
                                          ip = entry_point['mongo'], 
                                          cmd = '/service/sbin/startnode login',
                                          user = self.fabric.docker_user)
+            logging.warning(str(output))
             login_info = json.loads(str(output))
             entry_point['mongo_user'] = login_info['user']
             entry_point['mongo_pass'] = login_info['pass']
