@@ -1,9 +1,8 @@
 #!/bin/bash
 
+source /service/sbin/setup
+
 # Unmount gluster if necessary
 if [ $1 == "gluster" ]; then 
 	python /service/scripts/mounthelper.py umount
 fi
-
-# Now stop the ssh daemon. 
-pkill -f sshd
\ No newline at end of file
