@@ -2,9 +2,14 @@ import os
 import os.path
 import sys
 from pyspark import SparkContext
-from pyspark.mllib.regression import LinearRegressionWithSGD
+from pyspark.mllib.regression import LabeledPoint, LinearRegressionWithSGD
 from numpy import array
 
+# Load and parse the data
+def parsePoint(line):
+    values = [float(x) for x in line.replace(',', ' ').split(' ')]
+    return LabeledPoint(values[0], values[1:])
+
 if __name__ == "__main__":
     data_file = '/spark/data/lpsa.data'
 
@@ -15,13 +20,13 @@ if __name__ == "__main__":
         # Load and parse the data
         sc = SparkContext(sys.argv[1], "Logistic Regression")
         data = sc.textFile(data_file)
-        parsedData = data.map(lambda line: array([float(x) for x in line.replace(',', ' ').split(' ')]))
+        parsedData = data.map(parsePoint)
 
         # Build the model
         model = LinearRegressionWithSGD.train(parsedData)
 
         # Evaluate the model on training data
-        valuesAndPreds = parsedData.map(lambda point: (point.item(0),
-                                                       model.predict(point.take(range(1, point.size)))))
-        MSE = valuesAndPreds.map(lambda (v, p): (v - p)**2).reduce(lambda x, y: x + y)/valuesAndPreds.count()
+        valuesAndPreds = parsedData.map(lambda p: (p.label, 
+                                                   model.predict(p.features)))
+        MSE = valuesAndPreds.map(lambda (v, p): (v - p)**2).reduce(lambda x, y: x + y) / valuesAndPreds.count()
         print("Mean Squared Error = " + str(MSE))
